@@ -2,7 +2,7 @@
 
 """Base classes for one-off HTTP operations."""
 
-import simplejson
+import json
 
 from zope.component import getMultiAdapter, getUtility, queryMultiAdapter
 from zope.event import notify
@@ -138,7 +138,7 @@ class ResourceOperation(BatchingResourceMixin):
             # Serialize the result to JSON. Any embedded entries will be
             # automatically serialized.
             try:
-                result = simplejson.dumps(result, cls=ResourceJSONEncoder)
+                result = json.dumps(result, cls=ResourceJSONEncoder)
             except TypeError:
                 raise TypeError(
                     "Could not serialize object %s to JSON." % result
