@@ -31,10 +31,9 @@ from email.utils import formatdate
 import copy
 import hashlib
 import html
+import json
 from operator import itemgetter
 import os
-import simplejson
-import simplejson.encoder
 import sys
 import time
 
@@ -149,7 +148,7 @@ def decode_value(value):
     elif isinstance(value, bytes):
         return value.decode("utf-8")
     else:
-        return simplejson.dumps(value, cls=ResourceJSONEncoder)
+        return json.dumps(value, cls=ResourceJSONEncoder)
 
 
 def _default_html_renderer(value):
@@ -184,10 +183,10 @@ class LazrPageTemplateFile(TrustedAppPT, PageTemplateFile):
     pass
 
 
-class ResourceJSONEncoder(simplejson.encoder.JSONEncoderForHTML):
+class ResourceJSONEncoder(json.JSONEncoder):
     """A JSON encoder for JSON-exposable resources like entry resources.
 
-    This class works with simplejson to encode objects as JSON if they
+    This class works with json to encode objects as JSON if they
     implement IJSONPublishable. All EntryResource subclasses, for
     instance, should implement IJSONPublishable.
     """
@@ -196,15 +195,41 @@ class ResourceJSONEncoder(simplejson.encoder.JSONEncoderForHTML):
         self.media_type = kwargs.pop("media_type", HTTPResource.JSON_TYPE)
         super().__init__(*args, **kwargs)
 
+    # Based on simplejson.encoder.JSONEncoderForHTML.encode.
+    def encode(self, o):
+        # Override JSONEncoder.encode because it has hacks for performance
+        # that make things more complicated.
+        chunks = self.iterencode(o, True)
+        return "".join(chunks)
+
+    # Based on simplejson.encoder.JSONEncoderForHTML.iterencode.
+    def iterencode(self, o, _one_shot=False):
+        chunks = super().iterencode(o, _one_shot)
+        for chunk in chunks:
+            # These characters should be escaped in order to embed JSON
+            # content in a <script> tag.  They cannot be escaped with the
+            # usual entities (e.g. &amp;) because they are not expanded
+            # within <script> tags.
+            chunk = chunk.replace("&", "\\u0026")
+            chunk = chunk.replace("<", "\\u003c")
+            chunk = chunk.replace(">", "\\u003e")
+
+            if not self.ensure_ascii:
+                # The line separator and paragraph separator characters are
+                # not valid in JavaScript strings.
+                chunk = chunk.replace("\u2028", "\\u2028")
+                chunk = chunk.replace("\u2029", "\\u2029")
+
+            yield chunk
+
     def default(self, obj):
         """Convert the given object to a simple data structure."""
         if isProxy(obj):
             # We have a security-proxied version of a built-in
             # type. We create a new version of the type by copying the
             # proxied version's content. That way the container is not
-            # security proxied (and simplejson will know what do do
-            # with it), but the content will still be security
-            # wrapped.
+            # security proxied (and json will know what to do with it), but
+            # the content will still be security wrapped.
             underlying_object = removeSecurityProxy(obj)
             if isinstance(underlying_object, list):
                 return list(obj)
@@ -609,7 +634,7 @@ class BatchingResourceMixin:
         if not hasattr(entries, "__len__"):
             entries = IFiniteSequence(entries)
 
-        return simplejson.dumps(len(entries))
+        return json.dumps(len(entries))
 
     def batch(self, entries, request):
         """Prepare a batch from a (possibly huge) list of entries.
@@ -661,7 +686,7 @@ class BatchingResourceMixin:
         prev_url = navigator.prevBatchURL()
         if prev_url != "":
             batch["prev_collection_link"] = prev_url
-        json_string = simplejson.dumps(batch, cls=ResourceJSONEncoder)
+        json_string = json.dumps(batch, cls=ResourceJSONEncoder)
 
         # String together a bunch of entry representations, possibly
         # obtained from a representation cache.
@@ -1022,7 +1047,7 @@ class EntryManipulatingResource(ReadWriteResource):
             self.request.response.setStatus(415)
             return None, "Expected a media type of %s." % self.JSON_TYPE
         try:
-            h = simplejson.loads(representation.decode("utf-8"))
+            h = json.loads(representation.decode("utf-8"))
         except ValueError:
             self.request.response.setStatus(400)
             return None, "Entity-body was not a well-formed JSON document."
@@ -1352,7 +1377,7 @@ class EntryFieldResource(FieldUnmarshallerMixin, EntryManipulatingResource):
             name, value = self._unmarshallField(
                 self.context.name, self.context.field, CLOSEUP_DETAIL
             )
-            return simplejson.dumps(value)
+            return json.dumps(value)
         elif media_type == self.XHTML_TYPE:
             name, value = self.unmarshallFieldToHTML(
                 self.context.name, self.context.field
@@ -1770,7 +1795,7 @@ class EntryResource(
             if representation is None:
                 # Either there is no active cache, or the representation
                 # wasn't in the cache.
-                representation = simplejson.dumps(
+                representation = json.dumps(
                     self, cls=ResourceJSONEncoder, media_type=media_type
                 )
                 # If there's an active cache, and this representation
@@ -1799,13 +1824,13 @@ class EntryResource(
                     # redact certain fields, and reserialize
                     # it. Hopefully this is faster than generating the
                     # representation from scratch!
-                    json = simplejson.loads(representation)
+                    json_representation = json.loads(representation)
                     for field in redacted_fields:
-                        json[field] = self.REDACTED_VALUE
+                        json_representation[field] = self.REDACTED_VALUE
                     # There's no need to use the ResourceJSONEncoder,
                     # because we loaded the cached representation
                     # using the standard decoder.
-                    representation = simplejson.dumps(json)
+                    representation = json.dumps(json_representation)
             return representation
         elif media_type == self.XHTML_TYPE:
             return self.toXHTML()
@@ -1883,7 +1908,7 @@ class CollectionResource(
         if request is None:
             request = self.request
         result = super().batch(entries, request)
-        result += ', "resource_type_link" : ' + simplejson.dumps(self.type_url)
+        result += ', "resource_type_link" : ' + json.dumps(self.type_url)
         return result
 
     @property
@@ -1992,7 +2017,7 @@ class ServiceRootResource(HTTPResource):
         elif media_type == self.JSON_TYPE:
             # Serve a JSON map containing links to all the top-level
             # resources.
-            result = simplejson.dumps(self, cls=ResourceJSONEncoder)
+            result = json.dumps(self, cls=ResourceJSONEncoder)
 
         self.request.response.setHeader("Content-Type", media_type)
         return result.encode("utf-8")
