@@ -1,5 +1,3 @@
-from __future__ import absolute_import, print_function
-
 from zope.component import adapter
 from zope.interface import implementer, Interface
 from zope.schema import List, Text
@@ -9,19 +7,19 @@ from lazr.restful.example.base.interfaces import IRecipe
 from lazr.restful.declarations import (
     exported,
     exported_as_webservice_entry,
-    )
+)
 
 
 @exported_as_webservice_entry(contributes_to=[IRecipe])
 class IHasComments(Interface):
     comments = exported(
-        List(title=u'Comments made by users', value_type=Text()))
+        List(title="Comments made by users", value_type=Text())
+    )
 
 
 @implementer(IHasComments)
 @adapter(IRecipe)
 class RecipeToHasCommentsAdapter:
-
     def __init__(self, recipe):
         self.recipe = recipe
 
