@@ -1,11 +1,4 @@
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-
-__all__ = ['IKeyValuePair',
-           'IPairSet',
-           'KeyValuePair',
-           'PairSet']
+__all__ = ["IKeyValuePair", "IPairSet", "KeyValuePair", "PairSet"]
 
 from zope.component import getUtility
 from zope.interface import implementer
@@ -17,15 +10,15 @@ from lazr.restful.declarations import (
     exported,
     exported_as_webservice_collection,
     exported_as_webservice_entry,
-    )
+)
 from lazr.restful.interfaces import IServiceRootResource
 from lazr.restful.simple import TraverseWithGet
 
 
 @exported_as_webservice_entry()
 class IKeyValuePair(ILocation):
-    key = exported(Text(title=u"The key"))
-    value = exported(Text(title=u"The value"))
+    key = exported(Text(title="The key"))
+    value = exported(Text(title="The value"))
 
 
 @exported_as_webservice_collection(IKeyValuePair)
@@ -39,7 +32,7 @@ class IPairSet(ILocation):
 
 
 @implementer(IKeyValuePair, ILocation)
-class KeyValuePair(object):
+class KeyValuePair:
     """An object representing a key-value pair"""
 
     def __init__(self, set, key, value):
@@ -80,4 +73,4 @@ class PairSet(TraverseWithGet):
 
     @property
     def __name__(self):
-        return 'pairs'
+        return "pairs"
