@@ -2,14 +2,7 @@
 
 """Helpers for working with Zope interface."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-__all__ = [
-        'copy_attribute',
-        'copy_field',
-        'use_template'
-        ]
+__all__ = ["copy_attribute", "copy_field", "use_template"]
 
 import sys
 from copy import copy
@@ -25,20 +18,23 @@ def use_template(template, include=None, exclude=None):
     locals = frame.f_locals
 
     # Try to make sure we were called from a class def.
-    if (locals is frame.f_globals) or ('__module__' not in locals):
+    if (locals is frame.f_globals) or ("__module__" not in locals):
         raise TypeError(
-            "use_template() can only be used from within a class definition.")
+            "use_template() can only be used from within a class definition."
+        )
 
     if include and exclude:
         raise ValueError(
-            "you cannot use 'include' and 'exclude' at the same time.")
+            "you cannot use 'include' and 'exclude' at the same time."
+        )
 
     if exclude is None:
         exclude = []
 
     if include is None:
-        include = [name for name in template.names(True)
-                   if name not in exclude]
+        include = [
+            name for name in template.names(True) if name not in exclude
+        ]
 
     for name in include:
         locals[name] = copy_attribute(template.get(name))
@@ -82,4 +78,3 @@ def copy_field(field, **overrides):
     for name, value in overrides.items():
         setattr(field_copy, name, value)
     return field_copy
-
