@@ -17,8 +17,6 @@
 
 # pylint: disable-msg=W0401
 
-from __future__ import absolute_import, print_function
-
 __version__ = 1.0
 
 # Re-export in such a way that __version__ can still be imported if
@@ -27,10 +25,11 @@ try:
     # While we generally frown on "*" imports, this approach, combined with
     # the fact we only test code from this module, means that we can verify
     # what has been exported in the local files (DRY).
-    from lazr.restful.interfaces._fields import *
+    from lazr.restful.interfaces._fields import *  # noqa: F401, F403
     from lazr.restful.interfaces._fields import __all__ as _fields_all
-    from lazr.restful.interfaces._rest import *
+    from lazr.restful.interfaces._rest import *  # noqa: F401, F403
     from lazr.restful.interfaces._rest import __all__ as _rest_all
+
     __all__ = []
     __all__.extend(_fields_all)
     __all__.extend(_rest_all)
