@@ -24,11 +24,11 @@ __all__ = [
 from collections import OrderedDict
 from datetime import datetime
 from io import BytesIO
+import json
 import re
 from urllib.parse import unquote
 
 import pytz
-import simplejson
 
 from zope.datetime import (
     DateTimeError,
@@ -190,7 +190,7 @@ class SimpleFieldMarshaller:
                     v = v.decode("utf8")  # assume utf8
                 elif not isinstance(v, str):
                     v = str(v)
-                value = simplejson.loads(v)
+                value = json.loads(v)
             except (ValueError, TypeError):
                 # Pass the value as is. This saves client from having to encode
                 # strings.
