@@ -26,9 +26,9 @@
 
 """Implementation of the ws: namespace in TALES."""
 
+import json
 import operator
 import re
-import simplejson
 import textwrap
 from urllib.parse import quote
 
@@ -339,7 +339,7 @@ class WebLayerAPI:
         else:
             # Just dump it as JSON+XHTML
             resource = self.context
-        return simplejson.dumps(
+        return json.dumps(
             resource,
             cls=ResourceJSONEncoder,
             media_type=EntryResource.JSON_TYPE,
