@@ -2,10 +2,6 @@
 
 """Helper class for checking the event notifications."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-
 import zope.component
 
 
@@ -34,6 +30,4 @@ class TestEventListener:
     def unregister(self):
         """Stop the event listener from listening to events."""
         sm = zope.component.getGlobalSiteManager()
-        sm.unregisterHandler(
-            self, (self.object_type, self.event_type))
-
+        sm.unregisterHandler(self, (self.object_type, self.event_type))
