@@ -2,19 +2,16 @@
 
 """Helper functions for testing TALES expressions."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-
 __all__ = [
-    'test_tales',
-    ]
+    "test_tales",
+]
 
 from zope.pagetemplate.engine import TrustedEngine
 
 
 class Context:
     """A simple TALES context that only contains specified values."""
+
     def __init__(self, **kw):
         self.vars = kw
         self.contexts = kw
@@ -33,4 +30,3 @@ def test_tales(expression, **kw):
     # fail if an object is accessed or imported outside of page's namespace.
     compiled_tales = TrustedEngine.compile(expression)
     return compiled_tales(Context(**kw))
-
