@@ -21,9 +21,9 @@ __all__ = [
 from collections import OrderedDict
 from email.utils import quote as email_quote
 import io
+import json
 import random
 import re
-import simplejson
 import sys
 from types import ModuleType
 import unittest
@@ -194,7 +194,9 @@ def pformat_value(value):
     This is similar to `repr()`, but for doctest compatibility we format
     values in a way that is unambiguous across Python versions.
     """
-    if isinstance(value, OrderedDict):
+    if isinstance(value, list):
+        return "[" + ", ".join(pformat_value(item) for item in value) + "]"
+    elif isinstance(value, OrderedDict):
         # WebServiceResponseWrapper.jsonBody turns JSON objects into
         # OrderedDicts, but for doctest compatibility we just want to
         # re-sort and render these as if they were ordinary dicts.
@@ -455,7 +457,7 @@ class WebServiceCaller:
                 buf.write(value.read())
             else:
                 if not isinstance(value, str):
-                    value = simplejson.dumps(value)
+                    value = json.dumps(value)
                 lines = re.split(r"\r\n|\r|\n", value)
                 for line in lines[:-1]:
                     buf.write(line.encode())
@@ -523,7 +525,7 @@ class WebServiceCaller:
         This may mean turning the value into a JSON string.
         """
         if not isinstance(value, str):
-            value = simplejson.dumps(value)
+            value = json.dumps(value)
         return quote(value)
 
     def _make_request_with_entity_body(
@@ -583,7 +585,7 @@ class WebServiceResponseWrapper(ProxyBase):
         if isinstance(body, bytes):
             body = body.decode()
         try:
-            return simplejson.loads(body, object_pairs_hook=OrderedDict)
+            return json.loads(body, object_pairs_hook=OrderedDict)
         except ValueError:
             # Return a useful ValueError that displays the problematic
             # string, instead of one that just says the string wasn't
