@@ -17,9 +17,6 @@
 
 # pylint: disable=E0611,W0142
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = []
 
 import atexit
@@ -28,20 +25,25 @@ import os
 import re
 
 from pkg_resources import (
-    resource_filename, resource_exists, resource_listdir, cleanup_resources)
+    resource_filename,
+    resource_exists,
+    resource_listdir,
+    cleanup_resources,
+)
 from zope.testing import renormalizing
 from zope.testing.cleanup import cleanUp
 
 
 DOCTEST_FLAGS = (
-    doctest.ELLIPSIS |
-    doctest.NORMALIZE_WHITESPACE |
-    doctest.REPORT_NDIFF)
+    doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE | doctest.REPORT_NDIFF
+)
 
 
-checker = renormalizing.OutputChecker([
-    (re.compile(r'__builtin__\.'), 'builtins.'),
-    ])
+checker = renormalizing.OutputChecker(
+    [
+        (re.compile(r"__builtin__\."), "builtins."),
+    ]
+)
 
 
 def tearDown(test):
@@ -52,18 +54,23 @@ def tearDown(test):
 def load_tests(loader, tests, pattern):
     "Run the doc tests (README.txt and docs/*, if any exist)"
     doctest_files = []
-    if resource_exists('lazr.restful', 'docs'):
-        for name in resource_listdir('lazr.restful', 'docs'):
-            if name.endswith('.rst'):
+    if resource_exists("lazr.restful", "docs"):
+        for name in resource_listdir("lazr.restful", "docs"):
+            if name.endswith(".rst"):
                 doctest_files.append(
                     os.path.abspath(
-                        resource_filename('lazr.restful', 'docs/%s' % name)))
+                        resource_filename("lazr.restful", "docs/%s" % name)
+                    )
+                )
     atexit.register(cleanup_resources)
-    globs = {
-        'absolute_import': absolute_import,
-        'print_function': print_function,
-        }
-    tests.addTest(doctest.DocFileSuite(
-        *doctest_files, module_relative=False, optionflags=DOCTEST_FLAGS,
-        tearDown=tearDown, globs=globs, encoding='UTF-8', checker=checker))
+    tests.addTest(
+        doctest.DocFileSuite(
+            *doctest_files,
+            module_relative=False,
+            optionflags=DOCTEST_FLAGS,
+            tearDown=tearDown,
+            encoding="UTF-8",
+            checker=checker,
+        )
+    )
     return tests
